---
title: <span class="badge builder"></span> Filter
---
# <span class="badge builder"></span> Filter

## Constructor

```python
Filter()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.Filter
```

### <span class="badge object-method"></span> label

```python
def label(label: str) -> typing.Self
```

### <span class="badge object-method"></span> query

```python
def query(query: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [Filter](./object-Filter.md)
